@@ -1,15 +1,16 @@
 # Oxford University calendar conversion.
 # Simon Cozens (c) 1999-2002
 # Eugene van der Pijll (c) 2004
-# Dominic Hargreaves / University of Oxford (c) 2007-2009
+# Dominic Hargreaves / University of Oxford (c) 2007-2012
 # Artistic License
 package Oxford::Calendar;
-$Oxford::Calendar::VERSION = "2.03";
+$Oxford::Calendar::VERSION = "2.06";
 use strict;
 use Text::Abbrev;
 use Date::Calc qw(Add_Delta_Days Decode_Date_EU Delta_Days Mktime Easter_Sunday Date_to_Days Day_of_Week_to_Text Day_of_Week);
 use YAML;
 use Time::Seconds;
+use Time::Piece;
 
 use constant CALENDAR => '/etc/oxford-calendar.yaml';
 use constant SEVEN_WEEKS => 7 * ONE_WEEK;
@@ -31,8 +32,10 @@ Oxford::Calendar - University of Oxford calendar conversion routines
 
 =head1 SYNOPSIS
 
+    use 5.10.0;
     use Oxford::Calendar;
-    print "Today is ", Oxford::Calendar::ToOx(reverse Date::Calc::Today);
+    use Date::Calc;
+    say "Today is " . Oxford::Calendar::ToOx(reverse Date::Calc::Today);
 
 =head1 DESCRIPTION
 
@@ -150,7 +153,7 @@ sub _init_range {
     foreach my $termspec ( keys %db ) {
         next unless $db{$termspec};
 
-        my $time = eval { Mktime( Decode_Date_EU( $db{$termspec}->{start} ), 0, 0, 0 ) }
+        my $time = eval { Time::Piece->strptime($db{$termspec}->{start}, '%d/%m/%Y' ) }
              or die
                 "Could not decode date ($db{$termspec}->{start}) for term $termspec: $@";
 
@@ -195,7 +198,7 @@ sub _to_ox_nearest {
     my @term;
     _init_range() unless defined $_initrange;
     my $dow = Day_of_Week_to_Text( Day_of_Week( @date ) );
-    my $tm = Mktime((@date), 0, 0, 0);
+    my $tm = Time::Piece->strptime(join('/', @date[0..2]), '%Y/%m/%d');
     my @terms = sort { $a->[0] <=> $b->[0] } @_oxford_full_terms;
     my ( $prevterm, $nextterm );
     my $curterm = shift @terms;
@@ -324,8 +327,8 @@ sub ToOx {
         my $provisional = shift @term_start;
         die "Date out of range" unless ( $#term_start == 2 );
         my $days_from_start = Delta_Days( @term_start, @date );
-        my $week_offset = $days_from_start < 0 ? 0 : 1;
-        my $week = int( $days_from_start / 7 ) + $week_offset;
+        my $week_offset = $days_from_start < 0 ? 1 : 7;
+        my $week = int( ( $days_from_start + $week_offset ) / 7);
         return undef if $options->{confirmed} && $provisional;
         return undef if ( ( $week < 1 || $week > 8 ) && $mode eq 'full_term' );
         return ( $dow, $week, $term[1], $term[0] ) if ( wantarray );
@@ -524,9 +527,13 @@ sub Parse {
 
 =item FromOx($year, $term, $week, $day)
 
-Converts an Oxford date into a Georgian date, returning a string of the
+Converts an Oxford date into a Gregorian date, returning a string of the
 form C<DD/MM/YYYY> or undef.
 
+The arguments are of the same format as returned by ToOx in array context;
+that is, a four-digit year, the name of the term, the week number, and
+the name of the day of week (e.g. 'Sunday').
+
 If the requested date is not covered by the database, FromOx will die with
 an "out of range" error message. Therefore it is recommended to eval ToOx
 with appropriate error handling.
@@ -563,6 +570,10 @@ Bugs may be browsed and submitted at
 
 L<http://rt.cpan.org/Public/Dist/Display.html?Name=Oxford-Calendar>
 
+A copy of the maintainer's git repository may be found at
+
+L<https://github.com/jmdh/Oxford-Calendar>
+
 =head1 AUTHOR
 
 Simon Cozens is the original author of this module.
@@ -602,16 +613,22 @@ Calendar:
     start: 16/01/2011
   Hilary 2012:
     start: 15/01/2012
-    provisional: 1
   Hilary 2013:
     start: 13/01/2013
-    provisional: 1
   Hilary 2014:
     start: 19/01/2014
-    provisional: 1
   Hilary 2015:
     start: 18/01/2015
     provisional: 1
+  Hilary 2016:
+    start: 17/01/2016
+    provisional: 1
+  Hilary 2017:
+    start: 15/01/2017
+    provisional: 1
+  Hilary 2018:
+    start: 14/01/2018
+    provisional: 1
   Michaelmas 2001:
     start: 07/10/2001
   Michaelmas 2002:
@@ -634,16 +651,22 @@ Calendar:
     start: 10/10/2010
   Michaelmas 2011:
     start: 09/10/2011
-    provisional: 1
   Michaelmas 2012:
     start: 07/10/2012
-    provisional: 1
   Michaelmas 2013:
     start: 13/10/2013
-    provisional: 1
   Michaelmas 2014:
     start: 12/10/2014
     provisional: 1
+  Michaelmas 2015:
+    start: 11/10/2015
+    provisional: 1
+  Michaelmas 2016:
+    start: 09/10/2016
+    provisional: 1
+  Michaelmas 2017:
+    start: 08/10/2018
+    provisional: 1
   Trinity 2001:
     start: 22/04/2001
   Trinity 2002:
@@ -668,13 +691,19 @@ Calendar:
     start: 01/05/2011
   Trinity 2012:
     start: 22/04/2012
-    provisional: 1
   Trinity 2013:
     start: 21/04/2013
-    provisional: 1
   Trinity 2014:
     start: 27/04/2014
-    provisional: 1
   Trinity 2015:
     start: 26/04/2015
     provisional: 1
+  Trinity 2016:
+    start: 24/04/2016
+    provisional: 1
+  Trinity 2017:
+    start: 23/04/2017
+    provisional: 1
+  Trinity 2018:
+    start: 22/04/2018
+    provisional: 1
